@@ -47,11 +47,19 @@ def penguin(
     show_args: Optional[bool] = False,
     show_return: Optional[bool] = False,
     foreground: Optional[
-        Literal["red" "yellow", "green", "blue", "magenta", "cyan", "grey"]
+        Literal["red", "yellow", "green", "blue", "magenta", "cyan", "grey"]
     ] = "grey",
     background: Optional[
         Literal[
-            "red" "yellow", "green", "blue", "magenta", "cyan", "grey", "black", "white"
+            "red",
+            "yellow",
+            "green",
+            "blue",
+            "magenta",
+            "cyan",
+            "grey",
+            "black",
+            "white",
         ]
     ] = "black",
 ):
@@ -118,11 +126,19 @@ def penguin_async(
     show_args: Optional[bool] = False,
     show_return: Optional[bool] = False,
     foreground: Optional[
-        Literal["red" "yellow", "green", "blue", "magenta", "cyan", "grey"]
+        Literal["red", "yellow", "green", "blue", "magenta", "cyan", "grey"]
     ] = "grey",
     background: Optional[
         Literal[
-            "red" "yellow", "green", "blue", "magenta", "cyan", "grey", "black", "white"
+            "red",
+            "yellow",
+            "green",
+            "blue",
+            "magenta",
+            "cyan",
+            "grey",
+            "black",
+            "white",
         ]
     ] = "black",
 ):
@@ -139,9 +155,9 @@ def penguin_async(
         - default: `False`
     `show_return`: When `True`, it shows the function's return value(s).
         - default: `False`
-    `foreground`: When chosen from this list, `["red" "yellow", "green", "blue", "magenta", "cyan", "grey"]`, it colour the logger output **text** the chosen colour.
+    `foreground`: When chosen from this list, `["red", "yellow", "green", "blue", "magenta", "cyan", "grey"]`, it colour the logger output **text** the chosen colour.
         - default: `"grey"`
-    `background`: When chosen from this list, `["red" "yellow", "green", "blue", "magenta", "cyan", "grey", "black", "white"]`, it colour the logger output **background** the chosen colour.
+    `background`: When chosen from this list, `["red", "yellow", "green", "blue", "magenta", "cyan", "grey", "black", "white"]`, it colour the logger output **background** the chosen colour.
         - default: `"black"`
     """
 
